# Generated by Django 4.1.2 on 2022-10-17 17:13

from django.db import migrations
import wagtail.blocks
import wagtail.fields
import wagtail.images.blocks


class Migration(migrations.Migration):

    dependencies = [
        ('streamfield', '0010_auto_20210512_1426'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='gallery',
            options={'verbose_name': 'Galerie', 'verbose_name_plural': 'Galerie'},
        ),
        migrations.AlterField(
            model_name='gallery',
            name='stream',
            field=wagtail.fields.StreamField([('gallery_image', wagtail.blocks.StructBlock([('id', wagtail.images.blocks.ImageChooserBlock(icon='image', label='Image'))]))], use_json_field=True),
        ),
    ]
