# Generated by Django 4.1.2 on 2022-10-17 17:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sitesettings', '0002_auto_20210510_1431'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='imageslideritem',
            options={'verbose_name': 'Slider', 'verbose_name_plural': 'Sliders'},
        ),
        migrations.AlterModelOptions(
            name='sitesettingssection',
            options={'verbose_name': 'Slider', 'verbose_name_plural': 'Sliders'},
        ),
    ]
