# Generated by Django 3.1.10 on 2021-05-11 16:41

from django.db import migrations, models
import wagtail.blocks
import wagtail.fields
import wagtail.images.blocks


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('streamfield', '0003_delete_gallery'),
    ]

    operations = [
        migrations.CreateModel(
            name='Gallery',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(help_text='Gallery name', max_length=120)),
                ('stream', wagtail.fields.StreamField([('gallery_image', wagtail.blocks.StructBlock([('image', wagtail.images.blocks.ImageChooserBlock())], icon='image', label='Image'))])),
            ],
            options={
                'verbose_name': 'Gallery',
                'verbose_name_plural': 'Galleries',
            },
        ),
    ]
